@@ -1,9 +1,13 @@
 import psycopg2
 import pandas as pd
+import pkg_resources
 
 
 def select_table(conn, query_file, variables) -> pd.DataFrame:
-    with open(query_file, "r") as r_file:
+    sql_path = pkg_resources.resource_filename(__name__, query_file)
+    print(sql_path)
+
+    with open(sql_path, "r") as r_file:
         query = r_file.read()
     try:
         sql_query = pd.read_sql_query(sql=query, params=variables, con=conn)
@@ -14,12 +18,14 @@ def select_table(conn, query_file, variables) -> pd.DataFrame:
 
 
 def alter_table(conn, query_file, variables_as_tuple):
+    sql_path = pkg_resources.resource_filename(__name__, query_file)
+    print(sql_path)
     updated_rows = 0
     try:
         # create a new cursor
         cur = conn.cursor()
         # execute the UPDATE statement
-        with open(query_file, "r") as r_file:
+        with open(sql_path, "r") as r_file:
             query = r_file.read()
         cur.execute(query, variables_as_tuple)
         # get the number of updated rows
